@@ -1,44 +1,44 @@
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 import unittest
 
 from createsend.person import Person
 
 
-class PeopleTestCase(object):
+class PeopleTestCase:
 
     def test_get(self):
         email = "person@example.com"
         self.person.stub_request("clients/%s/people.json?email=%s" %
                                  (self.client_id, quote(email)), "person_details.json")
         person = self.person.get(self.client_id, email)
-        self.assertEquals(person.EmailAddress, email)
-        self.assertEquals(person.Name, "Person One")
-        self.assertEquals(person.AccessLevel, 1023)
-        self.assertEquals(person.Status, "Active")
+        self.assertEqual(person.EmailAddress, email)
+        self.assertEqual(person.Name, "Person One")
+        self.assertEqual(person.AccessLevel, 1023)
+        self.assertEqual(person.Status, "Active")
 
     def test_get_without_args(self):
         email = "person@example.com"
         self.person.stub_request("clients/%s/people.json?email=%s" %
                                  (self.client_id, quote(email)), "person_details.json")
         person = self.person.get()
-        self.assertEquals(person.EmailAddress, email)
-        self.assertEquals(person.Name, "Person One")
-        self.assertEquals(person.AccessLevel, 1023)
-        self.assertEquals(person.Status, "Active")
+        self.assertEqual(person.EmailAddress, email)
+        self.assertEqual(person.Name, "Person One")
+        self.assertEqual(person.AccessLevel, 1023)
+        self.assertEqual(person.Status, "Active")
 
     def test_add(self):
         self.person.stub_request("clients/%s/people.json" %
                                  self.client_id, "add_person.json")
         result = self.person.add(
             self.client_id, "person@example.com", "Person Name", 1023, "Password")
-        self.assertEquals(result.EmailAddress, "person@example.com")
+        self.assertEqual(result.EmailAddress, "person@example.com")
 
     def test_update(self):
         new_email = "new_email_address@example.com"
         self.person.stub_request("clients/%s/people.json?email=%s" %
                                  (self.client_id, quote(self.person.email_address)), None)
         self.person.update(new_email, "Person New Name", 31, 'blah')
-        self.assertEquals(self.person.email_address, new_email)
+        self.assertEqual(self.person.email_address, new_email)
 
     def test_delete(self):
         self.person.stub_request("clients/%s/people.json?email=%s" %
